@@ -2,13 +2,23 @@
 
 // General functions
 
-function sendViaWS (url, payload) {
+function sendViaWS (url, payload, success, failure) {
   var serialized = JSON.stringify(payload);
   ws = new WebSocket(url);
   ws.onmessage = function (evt) {
-    var message = evt.data;
-    //console.log( message );
-    humane.log( message );
+    var data = JSON.parse(evt.data);
+    console.log( data );
+
+    if ( data.message ) {
+      humane.log( data.message );
+    }
+
+    // handle success or failure callbacks
+    if ( data.success && success ) {
+      success( data );
+    } else if ( !data.success && failure) {
+      failure( data );
+    }
   };
   ws.onopen = function () {
     //console.log( "Sending ==> " + serialized );
